function y=blackscholescallvarplot3D(amount_invested,...
    stock_price,strike,r,mu,sigma,maturity, cl, hp)
%
% BSCALLVARPLOT3D Plots VaR of Black-Scholes call against 
% confidence level and holding period
%  
% Function plots the 3D VaR of a Black-Scholes call position 
% for specified cl and hp, and for chosen strike vector, as 
% illustrated in Figures 5A2.3 and 5A2.4.
%
% The first argument is the amount invested, the second is the stock price, the third is the 
% strike price, the fourth is the risk-free rate, the fifth is the mean return, the sixth is volatility,  
% the seventh is the term to maturity, the eighth is the confidence level and the last is 
% the holding period. Rates are expressed in annualised terms and periods in days.
% 
% Amount invested is positive (negative) if option position is long (short).
%
% Both confidence level and holding period are vectors.
%
% Revised by Kevin Dowd, November 11th, 2001.
% *****************************************************************************************
%
% VaR estimation
%
for i=1:length(cl)
    for j=1:length(hp)
        var(i,j)=blackscholescallvar_analytic(amount_invested,stock_price,strike,...
            r,mu,sigma,maturity, cl(i), hp(j)); %VaR 
    end
end
var=var';
%
% Plotting
%
surf(cl,hp,var);
axis;
xlabel('Confidence level','Fontweight','bold','vertical','bottom');
ylabel('Holding period','Fontweight','bold','vertical','bottom');
zlabel('VaR','rotation',0,'horizontal','right','Fontweight','bold');
title('VaR of Black-Scholes call position','FontSize',12,'Fontweight','bold');
shading interp;