function y=cornishfisheretl(mu, sigma, skew, kurtosis,cl)
% CORNISHFISHERETL Computes ETL using the Cornish-Fisher adjustment for non-normality
%
% Function estimates the ETL for near-normal P/L using the Cornish-Fisher adjustment for 
% non-normality, for specified confidence level.
% 
% The first four arguments are the first four moments of the P/L distribution. The fifth argument
% is the VaR confidence level.
% 
% cl must be a scalar, and hp is implied by data frequency. 
%
% Based on Peter Zangari, "A VaR methodology for portfolios that include options." RiskMetrics
% Monitor, First quarter, 1996, pp. 4-12.
% 
% Revised by Kevin Dowd, February 8th, 2001.
% ***************************************************************************************************
%
% ETL estimation
%
delta_cl=(1-cl)/100;
cl(1)=cl;
for i=1:98
    cl(i)=cl(1)+i*delta_cl;
    z(i)=norminv(1-cl(i),0,1);
    adjustment(i)=(1/6)*(z(i)^2-1)*skew+(1/24)*(z(i)^3-3*z(i))*(kurtosis-3)-(1/36)*(2*z(i)^3-5*z(i))*skew^2;
    VaR(i)=-sigma*(z(i)+adjustment(i))-mu; 
end
y=mean(VaR);