function y=hillestimator(data,tail_size)
% HILLESTIMATOR Estimates value of Hill estimator 
%   
%  HILLESTIMATOR estmates the value of the Hill estimator for a specified data 
% set and chosen tail size.
%
% The first argument is the data set, and the second is the number of observations
% to be used to estimate the Hill estimator.
% 
% Notes. (1) We estimate the Hill estimator by looking at the upper tail. (2) If the 
% specified tail size is such that any included observations are negative, the tail is truncated 
% at the point before observations become negative. (3) The tail size must be a scalar.
% 
%  Revised by Kevin Dowd, November 8th, 2001. 
% ************************************************************************
data=sort(data);
n=length(data);
i=find(data<=0); 
i=max(i);
k=min(tail_size,n-i);
logsum=0;
for i=2:k
    logsum=logsum+log(data(n-i));
end
y=logsum/(k-1)-log(data(n-k-1));
 