function y=hsetlplot2D_cl(PandL_data,cl)
% HSETLPLOT2D_CL Plots historical simulation ETL against confidence level 
%
% Function plots the historical simulation ETL of a portfolio against confidence level,
% for specified range of confidence level and holding period implied by data frequency.
% 
% The first argument is a vector of daily portfolio P/L data and the second
% is a vector of VaR confidence levels. 
%
% Revised by Kevin Dowd, November 26th, 2001.
% *****************************************************************************************
% 
% Determine if there are two arguments, and ensure that arguments
% are read as intended
%
if nargin<2,
    error('Too few arguments');
end
if nargin>2,
    error('Too many arguments');
end
if nargin ==2
    n=length(PandL_data);
end
% 
% Check that inputs have correct dimensions
%
[cl_rows,cl_cols]=size(cl);
if min(cl_rows,cl_cols)>1
    error('Confidence level must be a vector');
end
%
% Check that inputs obey sign and value restrictions
%
if max(cl)>=1
    error('Confidence level must be less than 1');
end
%
% ETL estimation
%
for k=1:length(cl);
    etl(k)=hsetl(PandL_data,cl(k));
end
% 
% Plotting
%
plot(cl,etl);
axis;
%
% Input data labels
%
% Axis labels
%
xlabel('Confidence level','Fontweight','bold');
ylabel('ETL','rotation',0,'horizontal','right','Fontweight','bold');
title(['Historical simulation ETL against confidence level'],'FontSize',12,'Fontweight','bold')



