function insurancevaretl(mu,sigma,n,p,theta, deductible,...
    no_of_trials, cl)
%
% INSURANCEVAR Generates Monte Carlo VaR and ETL for insurance
% portfolio in Chapter 6.5.
%
% The arguments are: the mean and volatility of returns, the 
% number of contracts, the probability of any loss event, the 
% expected profit per contract, the deductible, the number of 
% simulation trials, and the VaR confidence level.
%
% Revised by Kevin Dowd, November 8th, 2001.
% ************************************************************************************
%
M=no_of_trials;
D=deductible;
% n = no. of contracts
% p = probability of loss event
% theta=expected profit per contract
%
for j=1:M
    L(1,j)=binornd(1,p)*lognrnd(mu,sigma); % Realisation of L
    company_loss(1,j)=max(L(1,j)-D,0); % Adjust for deductible
    for i=2:n
        L(i,j)=binornd(1,p)*lognrnd(mu,sigma); % Realisation of L
        company_loss(i,j)=max(L(i,j)-D,0)+company_loss(i-1,j); % Adjust for deductible
    end
    total_company_loss(j)=company_loss(n,j); % Total company loss for given j trial
end
%
% Sample of total company losses
%
adjusted_total_company_loss=total_company_loss-mean(total_company_loss)-...
    theta*mean(total_company_loss)/n % Adjusts for premiums
%
Profit_or_loss=-adjusted_total_company_loss; % Convert to P/L
hist(adjusted_total_company_loss, 20)
%
hsvar(Profit_or_loss,cl)
hsetl(Profit_or_loss,cl)