function kupiecbacktest(PandL,VaR,cl)
% KUPIECBACKTEST Kupiec backtest 
%
% Function carries out the Kupeic backtest for a VaR risk measurement 
% model, for specified VaR confidence level.
%
% The first argument is a vector of portfolio P/L observations, 
% the second is a corresponding vector of VaR forecasts, and 
% the third is the VaR confidence level. 
% 
% This test presupposes that the number of observed excesses exceeds 
% number expected under null hypothesis. Must adjust accordingly
% if this does not hold.
% 
% The output consists of three terms: the probability that the P/L series observed are 
% consistent with a model that generates the VaR observations used in the test, the observed 
% of failures, and a 95% confidence interval for the frequency of failures.
% 
% Reference: Paul Kupiec, "Techniques for verifying the accuracy of risk measurement
% models." Journal of Derivatives, Winter 1995, p. 79.
%
% Revised by Kevin Dowd, April 20th, 2002.
% *****************************************************************************************
% 
n=length(PandL)              % Number of observations
p=1-cl                       % Probability of a failure each observation occurs
tail_losses=-PandL(-PandL>VaR);
x=length(tail_losses)                                  % Number of failures
probability_model_is_correct=1-binocdf(x,n,1-cl)
[obs_freq_of_failures,conf_int_for_freq_of_failures]=binofit(x,n,0.05)

