function y=lopezbacktest(PandL,VaR,cl)
% LOPEZ1BACKTEST First (binomial) Lopez forecast evaluation backtest score measure
%
% Function derives the first Lopez (ie, binomial) forecast evaluation 
% score for a VaR risk measurement model.
%
% The first argument is a vector of portfolio P/L observations, the second
% is a corresponding vector of VaR forecasts, and third is the VaR 
% confidence level. 
% 
% Reference: Jose A. Lopez, "Methods for evaluationg value-at-risk estimates." Federal 
% Reserve Bank of New York Economic Policy Review, October 1998, p. 121.
%
% Revised by Kevin Dowd, June 26th, 2001.
% *****************************************************************************************
%
n=length(PandL);
p=1-cl;
excess_loss=PandL-VaR;         % Derives excess loss
excess_loss(excess_loss<=0)=[];% Gets rid of negative or zero excess loss observations
x=length(excess_loss)         % Score for each positive excess loss obs
y=(2/n)*sum(x-n*p).^2;         % Score measure

