function y=normalquantilestandarderror(varargin)
% NORMALQUANTILESTANDARDERROR Estimates standard error of normal quantile estimate
%
% Function estimates the standard error of a normal quantile estimate. 
% 
% This function takes four or five arguments: the first is tail probability, the second is the 
% sample size from which the quantile is estimated, the third is the mean of the normal
% distribution, the fourth is the standard deviation of the distribution, and the fifth, 
% which is optional, is the bin size. The bin size is assumed to be 1 if it is not specified.
%
% The probability can be a vector. The other arguments are all scalars. The output is 
% a scalar or vector depending on whether the probability is a vector or scalar. 
%
% Revised by Kevin Dowd, March 15, 2001.
% *****************************************************************************************
% 
% Determine if there are four or five arguments, and ensure that arguments
% are read as intended
%
if nargin<4,
    error('Too few arguments');
end
if nargin>5,
    error('Too many arguments');
end
if nargin ==5
    prob=varargin{1};
    n=varargin{2};
    mu=varargin{3};
    sigma=varargin{4};
    bin_size=varargin{5};
end
if nargin==4
    prob=varargin{1};
    n=varargin{2};
    mu=varargin{3};
    sigma=varargin{4};
    bin_size=1;
end
%
% Check that inputs obey sign and value restrictions
%
if prob<0|prob>1
    error('Probability must be nonnegative and no greater than 1');
end
if n<=0
    error('Sample size must be positive');
end
if bin_size<=0
    error('Bin size must be greater than 0');
end
%
% Determination of frequency
%
x=norminv(prob,mu,sigma);
freq=normcdf(x+0.5*bin_size,mu,sigma)-normcdf(x-0.5*bin_size,mu,sigma);
%
% Standard error estimation
%
y=prob.*(1-prob)./(n*freq.^2); % Standard error 
