function y=tquantilestandarderror(varargin)
% TQUANTILESTANDARDERROR Estimates standard error of t quantile estimate
%
% Function estimates the standard error of a t quantile estimate. 
% 
% This function takes five or six arguments: the first is tail probability, the second is the 
% sample size from which the quantile is estimated, the third is the mean of the normal
% distribution, the fourth is the standard deviation of the distribution, the fifth is the 
% number of degrees of freedom of the t-distribution, and the sixth, 
% which is optional, is the bin size. The bin size is assumed to be 1 if it is not specified.
%
% The probability can be a vector. The other arguments are all scalars. The output is 
% a scalar or vector depending on whether the probability is a vector or scalar. 
%
% Revised by Kevin Dowd, March 15, 2001.
% *****************************************************************************************
% 
% Determine if there are five or six arguments, and ensure that arguments
% are read as intended
%
if nargin<5,
    error('Too few arguments');
end
if nargin>6,
    error('Too many arguments');
end
if nargin ==6
    prob=varargin{1};
    n=varargin{2};
    mu=varargin{3};
    sigma=varargin{4};
    df=varargin{5};
    bin_size=varargin{6};
end
if nargin==5
    prob=varargin{1};
    n=varargin{2};
    mu=varargin{3};
    sigma=varargin{4};
    df=varargin{5};
    bin_size=1;
end
%
% Check that inputs obey sign and value restrictions
%
if prob<0|prob>1
    error('Probability must be nonnegative and no greater than 1');
end
if n<=0
    error('Sample size must be positive');
end
if bin_size<=0
    error('Bin size must be greater than 0');
end
%
% Determination of frequency
%
x=mu+sigma*tinv(prob,df);
z=(x-mu)/sigma;
freq=tcdf((x+0.5*bin_size-mu)/sigma,df)-tcdf((x-0.5*bin_size-mu)/sigma,df);
%
% Standard error estimation
%
y=prob.*(1-prob)./(n*freq.^2); % Standard error 
