function y=AD_test_stat(number_trials,sample_size,confidence_interval)
% Produces plots of cumulative density for AD test, and confidence 
% interval for AD test stat.
%
% Inputs:
%   Number of trials.
%   Sizes of trial samples.
%   Confidence interval expressed as a fraction of 1.
%
% Revised by Kevin Dowd, January 4, 2005.
% *****************************************************************
tic
%
% Read back input parameters
%
number_trials
sample_size
m=number_trials;
n=sample_size;
confidence_interval
%
% Random number generation
%
data=zeros(m,n);
data=normrnd(0,1,m,n);
%
for i=1:m
   trial_sample=data(i,:);
   ordered_trial_sample=sort(trial_sample);
   for j=1:n
      term(j)=(2*j-1)*(log(normcdf(ordered_trial_sample(j),0,1))-...
          log(1-normcdf(ordered_trial_sample(n+1-j),0,1)));
   end
   AD_test_stat(i)=-n-mean(term);
end
AD_test_stat=sort(AD_test_stat);
%
% Obtain confidence interval
%
lower_bound_index=round(m*(1-confidence_interval)/2);
upper_bound_index=round(m*(confidence_interval+(1-confidence_interval)/2));
confidence_interval_for_KS_test_stat=[AD_test_stat(lower_bound_index) AD_test_stat(upper_bound_index)]
%
% Plot 
%
cdf=1/m:1/m:1;
plot(AD_test_stat,cdf)
xlabel('AD test statistic','horizontal','center','Fontweight','bold');
ylabel('Cumulative probability','rotation',90,'horizontal','center','Fontweight','bold');
title(['Cumulative density for AD test statistic'],'FontSize',12,'Fontweight','bold');
set(gcf, 'color', 'white');
%
toc
