function binomial_backtest(x,n,cl)
% Function carries out the binomial backtest for a VaR risk measurement 
% model, for specified VaR confidence level, for a one-sided H1.
%
% The first argument is the number of tail losses, 
% the second is the number of observations, and 
% the third is the VaR confidence level. 
% 
% Reference: Paul Kupiec, "Techniques for verifying the accuracy of risk measurement
% models." Journal of Derivatives, Winter 1995, p. 79.
%
% Revised by Kevin Dowd, Feb 28, 2005.
% *****************************************************************************************
% 
n              % Number of observations
p=1-cl         % Probability of a failure each observation occurs
x              % Number of failures
if x>=n*p % If number of exceedances greater than expected
    probability_model_is_correct=1-binocdf(x-1,n,1-cl)
else
    probability_model_is_correct=binocdf(x,n,1-cl)
end

