function y=blancoihlebacktest(PandL,VaR, ETL,cl)
% BLANCOIHLEBACKTEST Blanco-Ihle forecast evaluation backtest measure
%
% Function derives the Blanco-Ihle forecast evaluation loss measure for 
% a VaR risk measurement model.
%
% The first argument is a vector of portfolio P/L observations, the second 
% is a corresponding vector of VaR forecasts, the third a corresponding
% vector of ETL forecasts, and the fourth is the VaR confidence level.
%
% Reference: Carlos Blanco and Geoffrey Ihle. 1999. "How Good is Your VaR? 
% Using Backtesting to Assess System Performance." Financial Engineering News (August), 1-2. 
%
% Revised by Kevin Dowd, June 26th, 2001.
% *****************************************************************************************
%
n=length(PandL);
p=1-cl;
excess_loss=-PandL(-PandL>VaR);         % Derives excess loss
for i=1:length(excess_loss)
   benchmark(i)=(ETL(i)-VaR(i))/VaR(i);
   score(i)=(excess_loss(i)-VaR(i))/VaR(i)-benchmark(i);
end
y=(2/n)*sum(score).^2;        % First Blanco-Ihle score measure

