function y=christoffersen_backtest_for_unconditional_coverage(PandL,VaR,cl)
% Function carries out the Christoffersen backtest for unconditional
% coverage for a VaR risk measurement model, for specified VaR confidence level.
%
% The first argument is a vector of portfolio P/L observations, the second is a corresponding
% vector of VaR forecasts, and the third is the VaR confidence level. 
% 
% The output is the probability, given the data set, that the null hypothesis (ie, 
% a correct model) is correct. 
% 
% Reference: Peter F. Christoffersen, "Evaluating interval forecasts." International
% Economic Review, Vol. 39, 1998, pp.841-62.
%
% Revised by Kevin Dowd, Feb 28, 2005.
% *****************************************************************************************
% 
n=length(PandL);              % Number of observations
p=1-cl;                       % Probability of a failure under null hypothesis
[i,v]=find(VaR+PandL<0);
x=sum(v);                     % No. of failures
phat=x/n;                     % Frequency of failures
%
% Likelihood ratio test statistic
%
LR=-2*log(((p^x)*(1-p)^(n-x))/((phat^x)*((1-phat)^(n-x))));
% 
% Probability that null hypothesis (model) is correct
%
y=1-chi2cdf(LR,1);

