function gparetomultiplemefplots(x,mu,beta,zeta1,zeta2)
% GPARETOMULTIPLEMEFPLOTS Displays plots of empirical and 2 GP mean-excess-functions.
%   
%  Displays plots of empirical mean-excess function and two generalised Pareto 
% mean-excess functions which differ in their tail-index value. 
%
% The first argument is the data set, the second and third are the assumed
% values of the location and scale parameters. The last two are the alternative
% assumed tail index values.
%
%  Copyright 2001 Kevin Dowd. 
%  Revised Kevin Dowd, March 25, 2001. 
% **********************************************************************
x=sort(x);   
u=x;
n=length(u);
for i=1:n-1
    x=x(find(x>u(i)));
    mef(i)=mean(x)-u(i);
end
u=u';
u(u==max(u))=[];
gpmef1=(1+zeta1*(u-mu)/beta)/(1-zeta1);
gpmef2=(1+zeta2*(u-mu)/beta)/(1-zeta2);
plot(u,mef,u,gpmef1,u,gpmef2);
xlabel('Threshold (u)','Fontweight','bold');
ylabel('e(u)','rotation',0,'horizontal','right','Fontweight','bold');
title(['Empirical and Two Generalised Pareto Mean Excess Functions'],'FontSize',12,'Fontweight','bold');

   