function y=hsvaresplot2D_cl(PandL_data,cl)
% HSVARESPLOT2D_CL Plots historical simulation VaR and ES against confidence level 
%
% Function plots the historical simulation VaR and ES of a portfolio against confidence level,
% for specified range of confidence level and holding period implied by data frequency.
% 
% The first argument is a vector of daily portfolio P/L data and the second
% is a vector of VaR confidence levels. 
%
% Revised by Kevin Dowd, November 26th, 2001
% ******************************************************************************
% 
% Determine if there are two arguments, and ensure that arguments
% are read as intended
%
if nargin<2,
    error('Too few arguments');
end
if nargin>2,
    error('Too many arguments');
end
if nargin ==2
    n=length(PandL_data);
end
% 
% Check that inputs have correct dimensions
%
[cl_rows,cl_cols]=size(cl);
if min(cl_rows,cl_cols)>1
    error('Confidence level must be a vector');
end
%
% Check that inputs obey sign and value restrictions
%
if max(cl)>=1
    error('Confidence level must be less than 1');
end
%
% VaR and ES estimation
%
for k=1:length(cl);
    var(k)=hsvar(PandL_data,cl(k));
    es(k)=hses(PandL_data,cl(k));
end
% 
% Plotting
%
plot(cl,var,cl,es);
axis;
%
% Input data labels
%
% Axis labels
%
xlabel('Confidence level','Fontweight','bold');
ylabel('VaR/ES','rotation',90,'horizontal','center','Fontweight','bold');
title(['Historical simulation VaR and ES against confidence level'],'FontSize',12,'Fontweight','bold')
%
% VaR and ES labels
%
text(max(cl)-.4*(max(cl)-min(cl)),min(var)+.3*(max(var)-min(var)),'Upper line - ES');
text(max(cl)-.4*(max(cl)-min(cl)),min(var)+.2*(max(var)-min(var)),'Lower line - VaR');





