function dcpensionvar(mu,sigma,p,life_expectancy,number_trials,cl)
% DCPENSIONVAR Generates Monte Carlo VaR for DC pension in 
% Chapter 6.7.
%
% The arguments are as follows: expected rate of return on pension- 
% fund assets, volatility of rate of return of pension-fund assets,
% probability of unemployment in any period, life expectancy, number
% of trials, and VaR confidence level.
%
% Revised by Kevin Dowd, November 8th, 2001.
% ************************************************************************************
%
% PARAMETER SETTING
%
contribution_rate=0.15;
initial_income=25;
income_growth_rate=0.02;
M=number_trials;
L=life_expectancy;
% r is return on investment
%
for j=1:M
fund(1,j)=contribution_rate*initial_income;
years_contributed(1,j)=1;
    for i=2:40
        r(i,j)=mu+sigma*randn;
        employment_state(i,j)=binornd(1,1-p);
        employment_income(i,j)=initial_income*exp(income_growth_rate*(i-1));
        actual_income(i,j)=employment_state(i,j)*employment_income(i,j);
        contribution(i,j)=contribution_rate*actual_income(i,j);
        fund(i,j)=contribution(i,j)+fund(i-1,j)*(1+r(i,j));
        terminal_fund(j)=fund(i,j);
        terminal_return(j)=r(i,j);
        annuity_rate(j)=.04;
        pension(j)=payper(annuity_rate(j), L-65, terminal_fund(j));
        terminal_employment_income=(1-p)*initial_income*exp(income_growth_rate*39);
        pension_ratio(j)=pension(j)/terminal_employment_income;
    end
end
%
mean_pension_ratio=mean(pension_ratio);
std_pension_ratio=std(pension_ratio);
%
% PROFIT LOSS AND VAR
%
hist(pension_ratio, 20);
%
-hsvar(pension_ratio,cl)