function exercise10point4(stock_price,strike,r,mu,sigma,maturity,...
    number_simulation_trials,number_stock_price_increments,cl,hp)
% Function uses simulation to estimate European call VaR in Exercise 10.4.     
%       
% The arguments are: 
% * the current underlying price 
% * the strike
% * the risk-free rate
% * the mu of the underlying
% * the volatility of the underlying
% * the time to maturity of the option (in days)
% * the number of simulation trials
% * the number of stock price increments considered
% * the confidence level
% * the holding period (in days).
%
% Revised by Kevin Dowd, November 14, 2003
% 
% *************************************************************************
tic
% 
% SIMPLIFY NOTATION AND SET AND REPORT PARAMETERS
%
S=stock_price
X=strike
r
mu
maturity
cl
hp
M=number_simulation_trials
N=number_stock_price_increments
delta_t=hp/(365*N)
call_price=BS_option_price(S,X,r,sigma,maturity/365,1)
%
%   Simulate stock prices from 0 to end holding period
%
z=normrnd(0,1,N,M);
S=zeros(N,M); % Preallocate space
for i=1:N
     for j=1:M
         S(i,j)=stock_price*exp((mu-0.5*sigma^2)*i*delta_t+sigma*z(i,j)*sqrt(i*delta_t));
     end
end
%
%   Obtain terminal prices of options for above stock prices
%
option_price=zeros(N,M); payoff=zeros(N,M); % Preallocate space
for i=1:N
     for j=1:M
         option_price(i,j)=BS_option_price(S(i,j),X,r,sigma,(maturity-i*delta_t)/365,1);
     end
end
%
%   VaR estimation
%
c_star=prctile(option_price,100*(1-cl))
var=call_price-c_star
%
% ****************************************************************
% ****************************************************************
function y=BS_option_price(S,X,r,sigma,maturity,option_type)
% Black-Scholes option price
%
% Arguments as follows: the stock price, the strike price, the risk-free 
% rate, the volatility, the term to maturity (in years), and the option
% type (ie, 1 for call, 2 for put). 
%
d1=(log(S/X)+(r+(sigma^2)/2)*maturity)/(sigma*sqrt(maturity));
d2=d1-sigma*sqrt(maturity);
if option_type==1
    y=normcdf(d1)*S-exp(-r*maturity)*X*normcdf(d2);
else
    y=-normcdf(-d1)*S+exp(-r*maturity)*X*normcdf(-d2);
end
