function y=stoplosslognormalvar(mu,sigma,number_trials,loss_limit,cl,hp)
% STOPLOSSLOGNORMALVAR Generates Monte Carlo lognormal VaR with stop-loss limit
%
% The first argument is the mean arithmetic return, the second is the standard deviation
% of arithmetic returns, the third is the number of trials used in the simulations, the 
% fourth is the stop_loss limit, and the fifth and sixth are the confidence 
% level and holding period.
%
% Revised by Kevin Dowd, September 3rd, 2001.
% ************************************************************************************
%
N=100; % Number of increments, taken as 100 
dt=hp/N; % Size of time-increment
nudt=(mu-0.5*sigma^2)*dt;
sigmadt=sigma*sqrt(dt);
stock_price=1; % Stock price assumed to be investment assumed to be 1
lnS=log(stock_price);
M=number_trials;
L=loss_limit;
%
% Stock price simulation process
%
for i=1:M
    lnSt(i,1)=lnS+nudt+sigmadt*randn; 
    new_stock_price(i,1)=exp(lnSt(i,1));
    for j=2:N
        lnSt(i,j)=lnSt(i,j-1)+nudt+sigmadt*randn; 
        new_stock_price(i,j)=exp(lnSt(i,j)); % New stock price
        investment(i,j)=max(new_stock_price(i,j),stock_price-L);
    end
end
%
% P/L calculation
% 
for i=1:M
    Profit_or_loss(i)=investment(i,j)-stock_price;
end
y=hsvar(Profit_or_loss,cl);