function y=normalvarconfidenceinterval(mu,sigma,number_trials,...
    sample_size,cl,hp)
%
% NORMALVARCONFIDENCEINTERVAL Generates Monte Carlo 95% confidence 
% intervals for normal VaR
% 
% This function generates 95% confidence intervals for normal VaR 
% using Monte Carlo simulation. 
%
% The first argument is the mean of the P/L process, the second 
% is the standard deviation of the P/L process, the third is the 
% number of trials used in the simulations, the fourth is the size 
% of sample drawn in each trial, and the fifth and sixth are the 
% confidence level and holding period.
%
% Revised by Kevin Dowd, November 6th, 2001.
% **************************************************************
%
for k=1:number_trials
    z=randn(sample_size,1);
    x=(z+mu)/sigma;
    var(k)=normalvar(x,cl,hp);
end
var=sort(var);
lower_order_stat=floor(0.025*number_trials);
upper_order_stat=ceil(0.975*number_trials);
y=[var(lower_order_stat),var(upper_order_stat)];
